@@ -7,4 +7,6 @@ from .test_implicit import *
 from .test_password import *
 from .test_client_credential import *
 from .test_scopes import *
-from .test_rest_framework import *
\ No newline at end of file
+from .test_rest_framework import *
+from .test_application_views import *
+from .test_decorators import *
