@@ -3,17 +3,21 @@ from __future__ import unicode_literals
 import json
 
 from django.test import TestCase, RequestFactory
+from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.utils import timezone
 
-from ..compat import urlparse, parse_qs, urlencode, get_user_model
-from ..models import Application, Grant
+from ..compat import urlparse, parse_qs, urlencode
+from ..models import get_application_model, Grant
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
 
 from .test_utils import TestCaseUtils
 
 
+Application = get_application_model()
+
+
 # mocking a protected resource view
 class ResourceView(ProtectedResourceView):
     def get(self, request, *args, **kwargs):
@@ -23,8 +27,8 @@ class ResourceView(ProtectedResourceView):
 class BaseTest(TestCaseUtils, TestCase):
     def setUp(self):
         self.factory = RequestFactory()
-        self.test_user = get_user_model().objects.create_user("test_user", "test@user.com", "123456")
-        self.dev_user = get_user_model().objects.create_user("dev_user", "dev@user.com", "123456")
+        self.test_user = User.objects.create_user("test_user", "test@user.com", "123456")
+        self.dev_user = User.objects.create_user("dev_user", "dev@user.com", "123456")
 
         self.application = Application(
             name="Test Application",
@@ -35,7 +39,7 @@ class BaseTest(TestCaseUtils, TestCase):
         )
         self.application.save()
 
-        oauth2_settings.SCOPES = ['read', 'write']
+        oauth2_settings._SCOPES = ['read', 'write']
 
     def tearDown(self):
         self.application.delete()
@@ -54,7 +58,7 @@ class TestAuthorizationCodeView(BaseTest):
             'client_id': 'fakeclientid',
             'response_type': 'code',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 400)
@@ -72,7 +76,7 @@ class TestAuthorizationCodeView(BaseTest):
             'scope': 'read write',
             'redirect_uri': 'http://example.it',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
@@ -80,7 +84,7 @@ class TestAuthorizationCodeView(BaseTest):
         # check form is in context and form params are valid
         self.assertIn("form", response.context)
 
-        form = response.context.get("form")
+        form = response.context["form"]
         self.assertEqual(form['redirect_uri'].value(), "http://example.it")
         self.assertEqual(form['state'].value(), "random_state_string")
         self.assertEqual(form['scopes'].value(), "read write")
@@ -96,12 +100,12 @@ class TestAuthorizationCodeView(BaseTest):
             'client_id': self.application.client_id,
             'response_type': 'code',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
-        form = response.context.get("form")
+        form = response.context["form"]
         self.assertEqual(form['redirect_uri'].value(), "http://localhost")
 
     def test_pre_auth_forbibben_redirect(self):
@@ -115,7 +119,7 @@ class TestAuthorizationCodeView(BaseTest):
             'response_type': 'code',
             'redirect_uri': 'http://forbidden.it',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 400)
@@ -130,7 +134,7 @@ class TestAuthorizationCodeView(BaseTest):
             'client_id': self.application.client_id,
             'response_type': 'WRONG',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 302)
@@ -151,7 +155,7 @@ class TestAuthorizationCodeView(BaseTest):
             'allow': True,
         }
 
-        response = self.client.post(reverse('authorize'), data=form_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
         self.assertIn('http://example.it?', response['Location'])
         self.assertIn('state=random_state_string', response['Location'])
@@ -172,7 +176,7 @@ class TestAuthorizationCodeView(BaseTest):
             'allow': False,
         }
 
-        response = self.client.post(reverse('authorize'), data=form_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
         self.assertIn("error=access_denied", response['Location'])
 
@@ -191,7 +195,7 @@ class TestAuthorizationCodeView(BaseTest):
             'allow': True,
         }
 
-        response = self.client.post(reverse('authorize'), data=form_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
         self.assertIn('http://example.it?error', response['Location'])
 
@@ -210,7 +214,7 @@ class TestAuthorizationCodeView(BaseTest):
             'allow': True,
         }
 
-        response = self.client.post(reverse('authorize'), data=form_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=form_data)
         self.assertEqual(response.status_code, 400)
 
 
@@ -228,7 +232,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'allow': True,
         }
 
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         return query_dict['code'].pop()
 
@@ -246,7 +250,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
         content = json.loads(response.content.decode("utf-8"))
@@ -268,7 +272,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         self.assertTrue('refresh_token' in content)
 
@@ -277,7 +281,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'refresh_token': content['refresh_token'],
             'scope': content['scope'],
         }
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
         content = json.loads(response.content.decode("utf-8"))
@@ -297,7 +301,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         self.assertTrue('refresh_token' in content)
 
@@ -305,7 +309,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'grant_type': 'refresh_token',
             'refresh_token': content['refresh_token'],
         }
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
         content = json.loads(response.content.decode("utf-8"))
@@ -325,7 +329,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         self.assertTrue('refresh_token' in content)
 
@@ -334,7 +338,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'refresh_token': content['refresh_token'],
             'scope': 'read write nuke',
         }
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 401)
 
     def test_refresh_fail_repeating_requests(self):
@@ -351,7 +355,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         self.assertTrue('refresh_token' in content)
 
@@ -360,9 +364,9 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'refresh_token': content['refresh_token'],
             'scope': content['scope'],
         }
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
 
     def test_basic_auth_bad_authcode(self):
@@ -378,7 +382,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
 
     def test_basic_auth_bad_granttype(self):
@@ -394,7 +398,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
 
     def test_basic_auth_grant_expired(self):
@@ -413,7 +417,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
 
     def test_basic_auth_bad_secret(self):
@@ -430,7 +434,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, 'BOOM!')
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
 
     def test_public(self):
@@ -451,7 +455,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'client_secret':  self.application.client_secret,
         }
 
-        response = self.client.post(reverse('token'), data=token_request_data)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data)
         self.assertEqual(response.status_code, 200)
 
         content = json.loads(response.content.decode("utf-8"))
@@ -473,7 +477,7 @@ class TestAuthorizationCodeProtectedResource(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -485,7 +489,7 @@ class TestAuthorizationCodeProtectedResource(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
