@@ -3,15 +3,19 @@ from __future__ import unicode_literals
 import json
 
 from django.test import TestCase, RequestFactory
+from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 
-from ..compat import get_user_model
-from ..models import Application
+from ..models import get_application_model
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
 
 from .test_utils import TestCaseUtils
 
+
+Application = get_application_model()
+
+
 # mocking a protected resource view
 class ResourceView(ProtectedResourceView):
     def get(self, request, *args, **kwargs):
@@ -21,8 +25,8 @@ class ResourceView(ProtectedResourceView):
 class BaseTest(TestCaseUtils, TestCase):
     def setUp(self):
         self.factory = RequestFactory()
-        self.test_user = get_user_model().objects.create_user("test_user", "test@user.com", "123456")
-        self.dev_user = get_user_model().objects.create_user("dev_user", "dev@user.com", "123456")
+        self.test_user = User.objects.create_user("test_user", "test@user.com", "123456")
+        self.dev_user = User.objects.create_user("dev_user", "dev@user.com", "123456")
 
         self.application = Application(
             name="Test Password Application",
@@ -32,7 +36,7 @@ class BaseTest(TestCaseUtils, TestCase):
         )
         self.application.save()
 
-        oauth2_settings.SCOPES = ['read', 'write']
+        oauth2_settings._SCOPES = ['read', 'write']
 
     def tearDown(self):
         self.application.delete()
@@ -52,7 +56,7 @@ class TestPasswordTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
         content = json.loads(response.content.decode("utf-8"))
@@ -71,7 +75,7 @@ class TestPasswordTokenView(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
 
 
@@ -84,7 +88,7 @@ class TestPasswordProtectedResource(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
@@ -97,4 +101,4 @@ class TestPasswordProtectedResource(BaseTest):
 
         view = ResourceView.as_view()
         response = view(request)
-        self.assertEqual(response, "This is a protected resource")
\ No newline at end of file
+        self.assertEqual(response, "This is a protected resource")
