@@ -3,17 +3,21 @@ from __future__ import unicode_literals
 import json
 
 from django.test import TestCase, RequestFactory
+from django.contrib.auth.models import User
 from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import reverse
 
-from ..compat import urlparse, parse_qs, get_user_model
-from ..models import Application, Grant, AccessToken
+from ..compat import urlparse, parse_qs
+from ..models import get_application_model, Grant, AccessToken
 from ..settings import oauth2_settings
 from ..views import ScopedProtectedResourceView, ReadWriteScopedResourceView
 
 from .test_utils import TestCaseUtils
 
 
+Application = get_application_model()
+
+
 # mocking a protected resource view
 class ScopeResourceView(ScopedProtectedResourceView):
     required_scopes = ['scope1']
@@ -40,8 +44,8 @@ class ReadWriteResourceView(ReadWriteScopedResourceView):
 class BaseTest(TestCaseUtils, TestCase):
     def setUp(self):
         self.factory = RequestFactory()
-        self.test_user = get_user_model().objects.create_user("test_user", "test@user.com", "123456")
-        self.dev_user = get_user_model().objects.create_user("dev_user", "dev@user.com", "123456")
+        self.test_user = User.objects.create_user("test_user", "test@user.com", "123456")
+        self.dev_user = User.objects.create_user("dev_user", "dev@user.com", "123456")
 
         self.application = Application(
             name="Test Application",
@@ -52,7 +56,7 @@ class BaseTest(TestCaseUtils, TestCase):
         )
         self.application.save()
 
-        oauth2_settings.SCOPES = ['read', 'write', 'scope1', 'scope2', 'scope3']
+        oauth2_settings._SCOPES = ['read', 'write', 'scope1', 'scope2', 'scope3']
         oauth2_settings.READ_SCOPE = 'read'
         oauth2_settings.WRITE_SCOPE = 'write'
 
@@ -78,7 +82,7 @@ class TestScopesSave(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -100,7 +104,7 @@ class TestScopesSave(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -112,7 +116,7 @@ class TestScopesSave(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
@@ -136,7 +140,7 @@ class TestScopesProtection(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -148,7 +152,7 @@ class TestScopesProtection(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
@@ -178,7 +182,7 @@ class TestScopesProtection(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -190,7 +194,7 @@ class TestScopesProtection(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
@@ -220,7 +224,7 @@ class TestScopesProtection(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -232,7 +236,7 @@ class TestScopesProtection(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
@@ -262,7 +266,7 @@ class TestScopesProtection(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -274,7 +278,7 @@ class TestScopesProtection(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
@@ -303,7 +307,7 @@ class TestReadWriteScope(BaseTest):
             'response_type': 'code',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         query_dict = parse_qs(urlparse(response['Location']).query)
         authorization_code = query_dict['code'].pop()
 
@@ -315,31 +319,31 @@ class TestReadWriteScope(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         content = json.loads(response.content.decode("utf-8"))
         return content['access_token']
 
     def test_improperly_configured(self):
-        oauth2_settings.SCOPES = ['scope1']
+        oauth2_settings._SCOPES = ['scope1']
 
         request = self.factory.get("/fake")
         view = ReadWriteResourceView.as_view()
         self.assertRaises(ImproperlyConfigured, view, request)
 
-        oauth2_settings.SCOPES = ['read', 'write']
+        oauth2_settings._SCOPES = ['read', 'write']
         oauth2_settings.READ_SCOPE = 'ciccia'
 
         view = ReadWriteResourceView.as_view()
         self.assertRaises(ImproperlyConfigured, view, request)
 
     def test_properly_configured(self):
-        oauth2_settings.SCOPES = ['scope1']
+        oauth2_settings._SCOPES = ['scope1']
 
         request = self.factory.get("/fake")
         view = ReadWriteResourceView.as_view()
         self.assertRaises(ImproperlyConfigured, view, request)
 
-        oauth2_settings.SCOPES = ['read', 'write']
+        oauth2_settings._SCOPES = ['read', 'write']
         oauth2_settings.READ_SCOPE = 'ciccia'
 
         view = ReadWriteResourceView.as_view()
